version_info = (0, 8, 4)

__version__ = version = '.'.join(map(str, version_info))
__project__ = PROJECT = 'django-summernote'
__author__ = AUTHOR = "Park Hyunwoo <ez.amiryo@gmail.com>"


default_app_config = 'django_summernote.apps.DjangoSummernoteConfig'
